/*
 * PROJECT C Library, X68000 PROGRAMMING INTERFACE DEFINITION
 * --------------------------------------------------------------------
 * This file is written by the Project C Library Group,  and completely
 * in public domain. You can freely use, copy, modify, and redistribute
 * the whole contents, without this notice.
 * --------------------------------------------------------------------
 * $Id: errno.h,v 1.3 1994/07/27 13:43:14 mura Exp $
 */

#ifndef __errno_h__
#define __errno_h__

#ifndef __cdecl_h__
#include <cdecl.h>
#endif

#define EDOM         1
#define ERANGE       2
#define E2BIG        3
#define EACCES       4
#define EAGAIN       5
#define EBADF        6
#define EBUSY        7
#define ECHILD       8
#define EDEADLK      9
#define EEXIST       10
#define EFAULT       11
#define EFBIG        12
#define EINTR        13
#define EINVAL       14
#define EIO          15
#define EISDIR       16
#define ELOOP        17
#define EMFILE       18
#define EMLINK       19
#define ENAMETOOLONG 20
#define ENFILE       21
#define ENODEV       22
#define ENOENT       23
#define ENOEXEC      24
#define ENOLCK       25
#define ENOMEM       26
#define ENOSPC       27
#define ENOTBLK      28
#define ENOSYS       29
#define ENOTDIR      30
#define ENOTEMPTY    31
#define ENOTTY       32
#define ENXIO        33
#define EPERM        34
#define EPIPE        35
#define EROFS        36
#define ESPIPE       37
#define ETXTBSY      38
#define ESRCH        39
#define EXDEV        40
#define EDEVFS       41
#define EWOULDBLOCK  EDEADLK

/* ipc/network software -- argument errors */
#define	ENOTSOCK	62		/* Socket operation on non-socket */
#define	EDESTADDRREQ	63		/* Destination address required */
#define	EMSGSIZE	66		/* Message too long */
#define	EPROTOTYPE	77		/* Protocol wrong type for socket */
#define	ENOPROTOOPT	42		/* Protocol not available */
#define	EPROTONOSUPPORT	43		/* Protocol not supported */
#define	ESOCKTNOSUPPORT	44		/* Socket type not supported */
#define	EOPNOTSUPP	45		/* Operation not supported */
#define	EPFNOSUPPORT	46		/* Protocol family not supported */
#define	EAFNOSUPPORT	47		/* Address family not supported by protocol family */
#define	EADDRINUSE	48		/* Address already in use */
#define	EADDRNOTAVAIL	49		/* Can't assign requested address */

/* ipc/network software -- operational errors */
#define	ENETDOWN	50		/* Network is down */
#define	ENETUNREACH	51		/* Network is unreachable */
#define	ENETRESET	52		/* Network dropped connection on reset */
#define	ECONNABORTED	53		/* Software caused connection abort */
#define	ECONNRESET	54		/* Connection reset by peer */
#define	ENOBUFS		55		/* No buffer space available */
#define	EISCONN		56		/* Socket is already connected */
#define	ENOTCONN	57		/* Socket is not connected */
#define	ESHUTDOWN	58		/* Can't send after socket shutdown */
#define	ETOOMANYREFS	59		/* Too many references: can't splice */
#define	ETIMEDOUT	60		/* Operation timed out */
#define	ECONNREFUSED	61		/* Connection refused */


/* should be rearranged */
#define	EHOSTDOWN	64		/* Host is down */
#define	EHOSTUNREACH	65		/* No route to host */

/* quotas & mush */
#define	EPROCLIM	67		/* Too many processes */
#define	EUSERS		68		/* Too many users */
#define	EDQUOT		69		/* Disc quota exceeded */

/* Network File System */
#define	ESTALE		70		/* Stale NFS file handle */
#define	EREMOTE		71		/* Too many levels of remote in path */
#define	EBADRPC		72		/* RPC struct is bad */
#define	ERPCMISMATCH	73		/* RPC version wrong */
#define	EPROGUNAVAIL	74		/* RPC prog. not avail */
#define	EPROGMISMATCH	75		/* Program version wrong */
#define	EPROCUNAVAIL	76		/* Bad procedure for program */

#define	EFTYPE		79		/* Inappropriate file type or format */
#define	EAUTH		80		/* Authentication error */
#define	ENEEDAUTH	81		/* Need authenticator */
#define	ELAST		81		/* Must be equal largest errno */

extern __common char *sys_errlist[];
extern __common int_ sys_nerr;
extern __common volatile int_ errno;

#endif
